summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopeteview.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/ui/kopeteview.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/ui/kopeteview.h')
-rw-r--r--kopete/libkopete/ui/kopeteview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/ui/kopeteview.h b/kopete/libkopete/ui/kopeteview.h
index c54b1dba..99655e39 100644
--- a/kopete/libkopete/ui/kopeteview.h
+++ b/kopete/libkopete/ui/kopeteview.h
@@ -31,7 +31,7 @@ namespace Kopete
/**
* @author Jason Keirstead
*
* Abstract parent class for all types of views used for messaging.These view objects
* are provided by a @ref Kopete::ViewPlugin
*
* @see Kopete::ViewPlugin
@@ -42,7 +42,7 @@ class KOPETE_EXPORT KopeteView
/**
* constructor
*/
- KopeteView( Kopete::ChatSession *manager, Kopete::ViewPlugin *parent );
+ KopeteView( Kopete::ChatSession *manager, Kopete::ViewPlugin *tqparent );
virtual ~KopeteView();
/**
@@ -31,7 +31,7 @@ namespace Kopete
* @author Jason Keirstead
*
- * Abstract parent class for all types of views used for messaging.These view objects
+ * Abstract tqparent class for all types of views used for messaging.These view objects
* are provided by a @ref Kopete::ViewPlugin
*